==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModStructureSets.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.minecraft.class_3195;
import net.minecraft.class_5321;
import net.minecraft.class_6872;
import net.minecraft.class_6873;
import net.minecraft.class_6880;
import net.minecraft.class_7059;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModStructureSets {

    public static final class_5321<class_7059> ABANDONED_ALTAR = getOrCreateRegistryKey("abandoned_altar");
    public static final class_5321<class_7059> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_7059> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_7059> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_7059> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_7059> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_7059> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_7059> context) {
        class_7871<class_3195> structureLookup = context.method_46799(class_7924.field_41246);
        class_6880.class_6883<class_3195> abandonedAltarStructure = structureLookup.method_46747(ModStructures.ABANDONED_ALTAR);
        class_6880.class_6883<class_3195> abandonedToriiStructure = structureLookup.method_46747(ModStructures.ABANDONED_TORII);
        class_6880.class_6883<class_3195> miniBarStructure = structureLookup.method_46747(ModStructures.MINI_BAR);
        class_6880.class_6883<class_3195> outerShrineStructure = structureLookup.method_46747(ModStructures.OUTER_SHRINE);
        class_6880.class_6883<class_3195> bambooForestBBQStallStructure = structureLookup.method_46747(ModStructures.BAMBOO_FOREST_BBQ_STALL);
        class_6880.class_6883<class_3195> bambooForestHuyStructure = structureLookup.method_46747(ModStructures.BAMBOO_FOREST_HUT);
        class_6880.class_6883<class_3195> sakurazukaStructure = structureLookup.method_46747(ModStructures.SAKURAZUKA);
        context.method_46838(ABANDONED_ALTAR, new class_7059(abandonedAltarStructure, new class_6872(165, 25, class_6873.field_36421, 1947319134)));
        context.method_46838(ABANDONED_TORII, new class_7059(abandonedToriiStructure, new class_6872(165, 25, class_6873.field_36421, 2134619147)));
        context.method_46838(MINI_BAR, new class_7059(miniBarStructure, new class_6872(165, 25, class_6873.field_36421, 889525356)));
        context.method_46838(OUTER_SHRINE, new class_7059(outerShrineStructure, new class_6872(100, 20, class_6873.field_36421, 1319720890)));
        context.method_46838(BAMBOO_FOREST_BBQ_STALL, new class_7059(bambooForestBBQStallStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
        context.method_46838(BAMBOO_FOREST_HUT, new class_7059(bambooForestHuyStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
        context.method_46838(SAKURAZUKA, new class_7059(sakurazukaStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
    }

    public static class_6880.class_6883<class_7059> register(class_7891<class_7059> registry, class_5321<class_7059> registryKey, class_7059 structureSet) {
        return registry.method_46838(registryKey, structureSet);
    }

    public static class_5321<class_7059> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41248, ReverieDreams.id(name));
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModStructureSets.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import net.minecraft.class_3195;
import net.minecraft.class_5321;
import net.minecraft.class_6872;
import net.minecraft.class_6873;
import net.minecraft.class_6880;
import net.minecraft.class_7059;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModStructureSets {

    public static final class_5321<class_7059> ABANDONED_ALTAR = getOrCreateRegistryKey("abandoned_altar");
    public static final class_5321<class_7059> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_7059> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_7059> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_7059> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_7059> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_7059> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");
    public static final class_5321<class_7059> NETHER_HOT_SPRING = getOrCreateRegistryKey("nether_hot_spring");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_7059> context) {
        class_7871<class_3195> structureLookup = context.method_46799(class_7924.field_41246);
        class_6880.class_6883<class_3195> abandonedAltarStructure = structureLookup.method_46747(ModStructures.ABANDONED_ALTAR);
        class_6880.class_6883<class_3195> abandonedToriiStructure = structureLookup.method_46747(ModStructures.ABANDONED_TORII);
        class_6880.class_6883<class_3195> miniBarStructure = structureLookup.method_46747(ModStructures.MINI_BAR);
        class_6880.class_6883<class_3195> outerShrineStructure = structureLookup.method_46747(ModStructures.OUTER_SHRINE);
        class_6880.class_6883<class_3195> bambooForestBBQStallStructure = structureLookup.method_46747(ModStructures.BAMBOO_FOREST_BBQ_STALL);
        class_6880.class_6883<class_3195> bambooForestHuyStructure = structureLookup.method_46747(ModStructures.BAMBOO_FOREST_HUT);
        class_6880.class_6883<class_3195> sakurazukaStructure = structureLookup.method_46747(ModStructures.SAKURAZUKA);
        class_6880.class_6883<class_3195> netherHotSpringStructure = structureLookup.method_46747(ModStructures.NETHER_HOT_SPRING);
        context.method_46838(ABANDONED_ALTAR, new class_7059(abandonedAltarStructure, new class_6872(165, 25, class_6873.field_36421, 1947319134)));
        context.method_46838(ABANDONED_TORII, new class_7059(abandonedToriiStructure, new class_6872(165, 25, class_6873.field_36421, 2134619147)));
        context.method_46838(MINI_BAR, new class_7059(miniBarStructure, new class_6872(165, 25, class_6873.field_36421, 889525356)));
        context.method_46838(OUTER_SHRINE, new class_7059(outerShrineStructure, new class_6872(100, 20, class_6873.field_36421, 1319720890)));
        context.method_46838(BAMBOO_FOREST_BBQ_STALL, new class_7059(bambooForestBBQStallStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
        context.method_46838(BAMBOO_FOREST_HUT, new class_7059(bambooForestHuyStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
        context.method_46838(SAKURAZUKA, new class_7059(sakurazukaStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
        context.method_46838(NETHER_HOT_SPRING, new class_7059(netherHotSpringStructure, new class_6872(100, 20, class_6873.field_36421, 1191649132)));
    }

    public static class_6880.class_6883<class_7059> register(class_7891<class_7059> registry, class_5321<class_7059> registryKey, class_7059 structureSet) {
        return registry.method_46838(registryKey, structureSet);
    }

    public static class_5321<class_7059> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41248, ReverieDreams.id(name));
    }
}
